%%% Finite-Time Control in the Operational Space of Robot Manipulators
%%% Controllers: F2-(SP+D+GC),  A2-(SP+D+GC) %%%
%%% Run control section before running F2_A2_SP_JD_GC.sxl %%%
%% Control

clear all hidden
close all hidden
clc

P=eye(6,6)*2;
D=eye(6,6)*0.05;

q_init=[pi/2;pi/2;0;pi/8;pi/4;pi/2];
q_des=[-pi/4;0;0;0;pi/4;0];

T_init=gen_lite_kine(q_init);
Y_init=calc_X_RPY(T_init);

T_des=gen_lite_kine(q_des);
y_des=calc_X_RPY(T_des);

t_step=0.00004;
t_sim=15;

r1=1.5;
r2=1;

if 2*r2>r1 && r1>r2 && r2>0
    true
    p1=(2*r2-r1)/r1;
    p2=(2*r2-r1)/r2;
else
    false
end

%% Graphs SP+D+GC (F2-A2)
FZ=30;
FZ_l=25;
%%% Position 
figure('Name','Robot position','units','normalized','outerposition',[0 0 1 1], 'Color', [1 1 1])
subplot(3,2,1,'Position',[0.08 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.y_A2.time,out.y_A2.signals.values(1,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F2.time,out.y_F2.signals.values(1,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(m)$','Interpreter','latex','FontSize',FZ);
legend('$p_{x,A2}$','$p_{x,F2}$');
set(legend,'Interpreter','latex','Location','northeast','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,2,'Position',[0.57 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.error_A2.time,out.error_A2.signals.values(1,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F2.time,out.error_F2.signals.values(1,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
legend('$\tilde{y}_{x,A2}$','$\tilde{y}_{x,F2}$');
set(legend,'Interpreter','latex','Location','northeast','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,3,'Position',[0.08 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','','','','',''})
hold on 
plot(out.y_A2.time,out.y_A2.signals.values(2,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F2.time,out.y_F2.signals.values(2,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(m)$','Interpreter','latex','FontSize',FZ);
legend('$p_{y,A2}$','$p_{y,F2}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,4,'Position',[0.57 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.error_A2.time,out.error_A2.signals.values(2,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F2.time,out.error_F2.signals.values(2,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
legend('$\tilde{y}_{y,A2}$','$\tilde{y}_{y,F2}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,5,'Position',[0.08 0.15 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.y_A2.time,out.y_A2.signals.values(3,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F2.time,out.y_F2.signals.values(3,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(m)$','Interpreter','latex','FontSize',FZ);
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$p_{z,A2}$','$p_{z,F2}$');
set(legend,'Interpreter','latex','Orientation','horizontal','Location','east','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,6,'Position',[0.57 0.15 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.error_A2.time,out.error_A2.signals.values(3,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F2.time,out.error_F2.signals.values(3,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$\tilde{y}_{z,A2}$','$\tilde{y}_{z,F2}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

%% Orientation (RPY)
figure('Name','Robot orientation','units','normalized','outerposition',[0 0 1 1], 'Color', [1 1 1])
subplot(3,2,1,'Position',[0.08 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.y_A2.time,out.y_A2.signals.values(4,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F2.time,out.y_F2.signals.values(4,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(rad)$','Interpreter','latex','FontSize',FZ);
legend('$\phi_{\alpha,A2}$','$\phi_{\alpha,F2}$');
set(legend,'Interpreter','latex','Location','southeast','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,2,'Position',[0.57 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.error_A2.time,out.error_A2.signals.values(4,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F2.time,out.error_F2.signals.values(4,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
legend('$\tilde{y}_{\alpha,A2}$','$\tilde{y}_{\alpha,F2}$');
set(legend,'Interpreter','latex','Location','southeast','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,3,'Position',[0.08 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','','','','',''})
hold on 
plot(out.y_A2.time,out.y_A2.signals.values(5,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F2.time,out.y_F2.signals.values(5,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(rad)$','Interpreter','latex','FontSize',FZ);
legend('$\phi_{\beta,A2}$','$\phi_{\beta,F2}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,4,'Position',[0.57 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.error_A2.time,out.error_A2.signals.values(5,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F2.time,out.error_F2.signals.values(5,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
legend('$\tilde{y}_{\beta,A2}$','$\tilde{y}_{\beta,F2}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,5,'Position',[0.08 0.14 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.y_A2.time,out.y_A2.signals.values(6,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F2.time,out.y_F2.signals.values(6,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(rad)$','Interpreter','latex','FontSize',FZ);
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$\phi_{\gamma,A2}$','$\phi_{\gamma,F2}$');
set(legend,'Interpreter','latex','Orientation','horizontal','Location','east','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,6,'Position',[0.57 0.14 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.error_A2.time,out.error_A2.signals.values(6,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F2.time,out.error_F2.signals.values(6,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
xticks([0 5 10 15])
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$\tilde{y}_{\gamma,A2}$','$\tilde{y}_{\gamma,F2}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

%% Tau
LW=3;
figure('Name','Robot tau','units','normalized','outerposition',[0 0 1 1], 'Color', [1 1 1])
subplot(3,2,1,'Position',[0.08 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.tau_grav_F2.time,out.tau_grav_F2.signals.values(1,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
ylabel('$(N.m)$','Interpreter','latex','FontSize',FZ);
legend('$\tau_{q_1,F2}$');
set(legend,'Interpreter','latex','Location','north','Orientation','horizontal','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,2,'Position',[0.57 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.tau_grav_F2.time,out.tau_grav_F2.signals.values(2,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
legend('$\tau_{q_2,F2}$');
set(legend,'Interpreter','latex','Location','north','Orientation','horizontal','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,3,'Position',[0.08 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','','','','',''})
hold on 
plot(out.tau_grav_F2.time,out.tau_grav_F2.signals.values(3,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
ylabel('$(N.m)$','Interpreter','latex','FontSize',FZ);
legend('$\tau_{q_3,F2}$');
set(legend,'Interpreter','latex','Location','north','Orientation','horizontal','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,4,'Position',[0.57 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.tau_grav_F2.time,out.tau_grav_F2.signals.values(4,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
legend('$\tau_{q_4,F2}$');
set(legend,'Interpreter','latex','Location','north','Orientation','horizontal','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,5,'Position',[0.08 0.14 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.tau_grav_F2.time,out.tau_grav_F2.signals.values(5,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
ylabel('$(N.m)$','Interpreter','latex','FontSize',FZ);
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$\tau_{q_5,F2}$');
set(legend,'Interpreter','latex','Orientation','horizontal','Location','north','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,6,'Position',[0.57 0.14 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.tau_grav_F2.time,out.tau_grav_F2.signals.values(6,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
box on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$\tau_{q_6,F2}$');
set(legend,'Interpreter','latex','Location','north','Orientation','horizontal','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

