%%% Finite-Time Control in the Operational Space of Robot Manipulators
%%% Controllers: F4-(SP+SJD+GC),  A4-(SP+SJD+GC) %%%
%%% Run control section before running F4_A4_SP_SJD_GC.sxl %%%
%% Control

clear all 
close all 
clc

P=diag([3 2 3 2 2 2]);
D=eye(6,6)*0.1;

q_init=[pi/2;pi/2;0;pi/8;pi/4;pi/2];
q_des=[-pi/4;0;0;0;pi/4;0];

T_init=gen_lite_kine(q_init);
Y_init=calc_X_RPY(T_init);

T_des=gen_lite_kine(q_des);
y_des=calc_X_RPY(T_des);

t_step=0.00004;
t_sim=15;

r1=1.5;
r2=1;

if 2*r2>r1 && r1>r2 && r2>0
    true
    p1=(2*r2-r1)/r1;
    p2=(2*r2-r1)/r2;
else
    false
end

%% Graphs SP+SJD+GC (F4-A4)
FZ=30;
FZ_l=25;
%%% Position 
figure('Name','Robot position','units','normalized','outerposition',[0 0 1 1], 'Color', [1 1 1])
subplot(3,2,1,'Position',[0.08 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.y_A4.time,out.y_A4.signals.values(1,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F4.time,out.y_F4.signals.values(1,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(m)$','Interpreter','latex','FontSize',FZ);
legend('$p_{x,A4}$','$p_{x,F4}$');
set(legend,'Interpreter','latex','Location','northeast','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,2,'Position',[0.57 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.error_A4.time,out.error_A4.signals.values(1,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F4.time,out.error_F4.signals.values(1,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
legend('$\tilde{y}_{x,A4}$','$\tilde{y}_{x,F4}$');
set(legend,'Interpreter','latex','Location','northeast','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,3,'Position',[0.08 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','','','','',''})
hold on 
plot(out.y_A4.time,out.y_A4.signals.values(2,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F4.time,out.y_F4.signals.values(2,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(m)$','Interpreter','latex','FontSize',FZ);
legend('$p_{y,A4}$','$p_{y,F4}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,4,'Position',[0.57 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.error_A4.time,out.error_A4.signals.values(2,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F4.time,out.error_F4.signals.values(2,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
legend('$\tilde{y}_{y,A4}$','$\tilde{y}_{y,F4}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,5,'Position',[0.08 0.15 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.y_A4.time,out.y_A4.signals.values(3,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F4.time,out.y_F4.signals.values(3,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(m)$','Interpreter','latex','FontSize',FZ);
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$p_{z,A4}$','$p_{z,F4}$');
set(legend,'Interpreter','latex','Orientation','horizontal','Location','east','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,6,'Position',[0.57 0.15 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.error_A4.time,out.error_A4.signals.values(3,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F4.time,out.error_F4.signals.values(3,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$\tilde{y}_{z,A4}$','$\tilde{y}_{z,F4}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

%% Orientation (RPY)
figure('Name','Robot orientation','units','normalized','outerposition',[0 0 1 1], 'Color', [1 1 1])
subplot(3,2,1,'Position',[0.08 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.y_A4.time,out.y_A4.signals.values(4,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F4.time,out.y_F4.signals.values(4,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(rad)$','Interpreter','latex','FontSize',FZ);
legend('$\phi_{\alpha,A4}$','$\phi_{\alpha,F4}$');
set(legend,'Interpreter','latex','Location','southeast','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,2,'Position',[0.57 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.error_A4.time,out.error_A4.signals.values(4,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F4.time,out.error_F4.signals.values(4,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
legend('$\tilde{y}_{\alpha,A4}$','$\tilde{y}_{\alpha,F4}$');
set(legend,'Interpreter','latex','Location','southeast','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,3,'Position',[0.08 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','','','','',''})
hold on 
plot(out.y_A4.time,out.y_A4.signals.values(5,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F4.time,out.y_F4.signals.values(5,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(rad)$','Interpreter','latex','FontSize',FZ);
legend('$\phi_{\beta,A4}$','$\phi_{\beta,F4}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,4,'Position',[0.57 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.error_A4.time,out.error_A4.signals.values(5,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F4.time,out.error_F4.signals.values(5,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
legend('$\tilde{y}_{\beta,A4}$','$\tilde{y}_{\beta,F4}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,5,'Position',[0.08 0.14 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.y_A4.time,out.y_A4.signals.values(6,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.y_F4.time,out.y_F4.signals.values(6,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
ylabel('$(rad)$','Interpreter','latex','FontSize',FZ);
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$\phi_{\gamma,A4}$','$\phi_{\gamma,F4}$');
set(legend,'Interpreter','latex','Orientation','horizontal','Location','east','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,6,'Position',[0.57 0.14 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.error_A4.time,out.error_A4.signals.values(6,:),'LineWidth',3.5,'LineStyle','--','Color',[0,1,0])
plot(out.error_F4.time,out.error_F4.signals.values(6,:),'LineWidth',3.5,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
xticks([0 5 10 15])
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$\tilde{y}_{\gamma,A4}$','$\tilde{y}_{\gamma,F4}$');
set(legend,'Interpreter','latex','Location','east','Orientation','horizontal','NumColumns',1,'FontSize',FZ_l)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

%% Tau
LW=2;
figure('Name','Robot tau','units','normalized','outerposition',[0 0 1 1], 'Color', [1 1 1])
subplot(3,2,1,'Position',[0.08 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.tau_grav_F4.time,out.tau_grav_F4.signals.values(1,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
ylabel('$(N.m)$','Interpreter','latex','FontSize',FZ);
legend('$\tau_{q_1,F4}$');
set(legend,'Interpreter','latex','Location','north','Orientation','horizontal','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,2,'Position',[0.57 0.73 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.tau_grav_F4.time,out.tau_grav_F4.signals.values(2,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
legend('$\tau_{q_2,F4}$');
set(legend,'Interpreter','latex','Location','north','Orientation','horizontal','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,3,'Position',[0.08 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','','','','',''})
hold on 
plot(out.tau_grav_F4.time,out.tau_grav_F4.signals.values(3,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
ylabel('$(N.m)$','Interpreter','latex','FontSize',FZ);
legend('$\tau_{q_3,F4}$');
set(legend,'Interpreter','latex','Location','north','Orientation','horizontal','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,4,'Position',[0.57 0.44 0.41 0.24],'FontSize',FZ,'XTickLabel',{'','','','',''})
hold on 
plot(out.tau_grav_F4.time,out.tau_grav_F4.signals.values(4,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
legend('$\tau_{q_4,F4}$');
set(legend,'Interpreter','latex','Location','north','Orientation','horizontal','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,5,'Position',[0.08 0.14 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.tau_grav_F4.time,out.tau_grav_F4.signals.values(5,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
ylabel('$(N.m)$','Interpreter','latex','FontSize',FZ);
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$\tau_{q_5,F4}$');
set(legend,'Interpreter','latex','Orientation','horizontal','Location','north','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

subplot(3,2,6,'Position',[0.57 0.14 0.41 0.24],'FontSize',FZ)
hold on 
plot(out.tau_grav_F4.time,out.tau_grav_F4.signals.values(6,:),'LineWidth',LW,'Color',[0,0,1])
hold off 
grid on
xlim([0 15])
ylim([-15 15])
xticks([0 5 10 15])
xlabel('$Time\:(s)$','Interpreter','latex','FontSize',FZ);
legend('$\tau_{q_6,F4}$');
set(legend,'Interpreter','latex','Location','north','Orientation','horizontal','FontSize',FZ)
set(gca,'LineWidth',3);
set(gca,'TickLabelInterpreter','latex')

